@@ -15,6 +15,7 @@ class _DataFrame:
 
 
     def Read(self):
+
         if not Auth.tokenValid():
             Auth.refreshToken()
 
@@ -23,8 +24,6 @@ class _DataFrame:
         })
 
         data = []
-        columns = []
-        indices = list(range(0, response.json()["data"]["items"]))
 
         loopCount = math.ceil(response.json()["data"]["items"] / 500)
         for x in range(0, loopCount):
@@ -32,15 +31,12 @@ class _DataFrame:
                 'Authorization': 'Bearer ' + settings.token
             })
 
-            if x is 0:
-                columns = list(response.json()["data"]["items"][0]["data"].keys())
-
             for item in response.json()["data"]["items"]:
-                data.append(list(item["data"].values()))
+                data.append(item["data"])
+
+        return pd.DataFrame(data)
 
-        return pd.DataFrame(data, index=indices, columns=columns)
         
-
     def Synchronize(self, dataframe):
         if not Auth.tokenValid():
             Auth.refreshToken()
@@ -97,5 +93,4 @@ class _DataFrame:
 
             count += 1
 
-        return True
-
+        return True
\ No newline at end of file
